%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not modify this file since it was automatically generated from:
% 
%  RspDirective.R
% 
% by the Rdoc compiler part of the R.oo package.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{getType.RspPageDirective}
\alias{getType.RspPageDirective}
\alias{RspPageDirective.getType}
\alias{getType,RspPageDirective-method}

\title{Gets the content type}

\description{
 Gets the content type.
}

\usage{
\method{getType}{RspPageDirective}(directive, default=NA, as=c("text", "IMT"), ...)
}

\arguments{
  \item{default}{If unknown/not set, the default content type to return.}
  \item{...}{Not used.}
}

\value{
 Returns a \code{\link[base]{character}} string.
}

\author{Henrik Bengtsson}

\seealso{
  For more information see \code{\link{RspPageDirective}}.
}
\keyword{internal}
\keyword{methods}
